# Changelog

All notable changes to this project will be documented in this file.

## 0.1.2 - 2025-11-27

### Added

- Ternary accepts pandas expressions as args or `c`, `s`, `v` kwargs
- Ternary contour added
- Client for postresql petrodb database API
- accessors plotting methods plot, heatmap and boxplot Added
- drop columns with only `NA` by default

### Fixed

- pyroxene recoded
- molprop method available for all accessors
- oxides order could be defined in config

## 0.1.1 - 2025-10-27

- Initial release
